[![Pub Version](https://img.shields.io/pub/v/elevarm_ui?color=blueviolet)](https://pub.dev/packages/elevarm_ui)

Elevarm design system for Flutter.

## Features

- `ElevarmColors` for standardized coloring.
- `ElevarmFonts`, `ElevarmFontWeights`, `ElevarmFontSizes` for standardized typography (in development).

## Getting started

1. Initialize font configurations by calling `ElevarmFonts.init` method in main function:
   ```dart
   import 'package:elevarm_ui/elevarm_ui.dart';

   void main() {
       ElevarmFonts.init(
       allowRuntimeFetching: true,
       );
   
       runApp(const MyApp());
   }
   ```
2. Set the app's theme by passing `ElevarmThemeData` in `MaterialApp`:
   ```dart
   import 'package:elevarm_ui/elevarm_ui.dart';

   MaterialApp(
      theme: ElevarmThemeData.light(),
   );
   ```
3. You're finished! Now you can start using `elevarm_ui` classes below.

## A. Color

Colors are located in `ElevarmColors` class.

### a.1. Neutral Colors

|                                                          | Shade | Color     |
| -------------------------------------------------------- | ----- | --------- |
| ![#E7E8EA](https://placehold.co/10x10/E7E8EA/E7E8EA.png) | 100   | `#E7E8EA` |
| ![#B1B4B9](https://placehold.co/10x10/B1B4B9/B1B4B9.png) | 200   | `#B1B4B9` |
| ![#7C8089](https://placehold.co/10x10/7C8089/7C8089.png) | 300   | `#7C8089` |
| ![#464C58](https://placehold.co/10x10/464C58/464C58.png) | 400   | `#464C58` |
| ![#101828](https://placehold.co/10x10/101828/101828.png) | 500   | `#101828` |

### a.2. Grey Colors

|                                                          | Shade         | Color     |
| -------------------------------------------------------- | ------------- | --------- |
| ![#FCFCFD](https://placehold.co/10x10/FCFCFD/FCFCFD.png) | 25            | `#FCFCFD` |
| ![#F2F4F7](https://placehold.co/10x10/F2F4F7/F2F4F7.png) | 100           | `#F2F4F7` |
| ![#EAECF0](https://placehold.co/10x10/EAECF0/EAECF0.png) | 200           | `#EAECF0` |
| ![#D0D5DD](https://placehold.co/10x10/D0D5DD/D0D5DD.png) | 300           | `#D0D5DD` |
| ?                                                        | 400           | ?         |
| ![#667085](https://placehold.co/10x10/667085/667085.png) | 500 (Default) | `#667085` |
| ![#475467](https://placehold.co/10x10/475467/475467.png) | 600           | `#475467` |
| ![#344054](https://placehold.co/10x10/344054/344054.png) | 700           | `#344054` |
| ?                                                        | 800           | ?         |
| ![#101828](https://placehold.co/10x10/101828/101828.png) | 900           | `#101828` |

### a.3. Primary Colors

|                                                          | Shade         | Color     |
| -------------------------------------------------------- | ------------- | --------- |
| ![#EAECF9](https://placehold.co/10x10/EAECF9/EAECF9.png) | 100           | `#EAECF9` |
| ![#B9C0EA](https://placehold.co/10x10/B9C0EA/B9C0EA.png) | 200           | `#B9C0EA` |
| ![#8995DC](https://placehold.co/10x10/8995DC/8995DC.png) | 300           | `#8995DC` |
| ![#5869CD](https://placehold.co/10x10/5869CD/5869CD.png) | 400           | `#5869CD` |
| ![#283EBF](https://placehold.co/10x10/283EBF/283EBF.png) | 500 (Default) | `#283EBF` |
| ![#2235A4](https://placehold.co/10x10/2235A4/2235A4.png) | 600           | `#2235A4` |
| ![#1D2D8A](https://placehold.co/10x10/1D2D8A/1D2D8A.png) | 700           | `#1D2D8A` |
| ![#17246F](https://placehold.co/10x10/17246F/17246F.png) | 800           | `#17246F` |
| ![#121B54](https://placehold.co/10x10/121B54/121B54.png) | 900           | `#121B54` |

### a.4. Info Colors

|                                                          | Shade         | Color     |
| -------------------------------------------------------- | ------------- | --------- |
| ![#E6F1FC](https://placehold.co/10x10/E6F1FC/E6F1FC.png) | 100           | `#E6F1FC` |
| ![#ADD1F6](https://placehold.co/10x10/ADD1F6/ADD1F6.png) | 200           | `#ADD1F6` |
| ![#75B0EF](https://placehold.co/10x10/75B0EF/75B0EF.png) | 300           | `#75B0EF` |
| ![#3D90E9](https://placehold.co/10x10/3D90E9/3D90E9.png) | 400           | `#3D90E9` |
| ![#0470E2](https://placehold.co/10x10/0470E2/0470E2.png) | 500 (Default) | `#0470E2` |
| ![#0360C2](https://placehold.co/10x10/0360C2/0360C2.png) | 600           | `#0360C2` |
| ![#0351A3](https://placehold.co/10x10/0351A3/0351A3.png) | 700           | `#0351A3` |
| ![#024183](https://placehold.co/10x10/024183/024183.png) | 800           | `#024183` |
| ![#023163](https://placehold.co/10x10/023163/023163.png) | 900           | `#023163` |

### a.5. Success Colors

|                                                          | Shade         | Color     |
| -------------------------------------------------------- | ------------- | --------- |
| ![#ECFDF3](https://placehold.co/10x10/ECFDF3/ECFDF3.png) | 50            | `#ECFDF3` |
| ![#E9F7E7](https://placehold.co/10x10/E9F7E7/E9F7E7.png) | 100           | `#E9F7E7` |
| ![#B8E4B0](https://placehold.co/10x10/B8E4B0/B8E4B0.png) | 200           | `#B8E4B0` |
| ![#87D179](https://placehold.co/10x10/87D179/87D179.png) | 300           | `#87D179` |
| ![#55BF43](https://placehold.co/10x10/55BF43/55BF43.png) | 400           | `#55BF43` |
| ![#24AC0C](https://placehold.co/10x10/24AC0C/24AC0C.png) | 500 (Default) | `#24AC0C` |
| ![#1F940A](https://placehold.co/10x10/1F940A/1F940A.png) | 600           | `#1F940A` |
| ![#1A7C09](https://placehold.co/10x10/1A7C09/1A7C09.png) | 700           | `#1A7C09` |
| ![#156407](https://placehold.co/10x10/156407/156407.png) | 800           | `#156407` |
| ![#104C05](https://placehold.co/10x10/104C05/104C05.png) | 900           | `#104C05` |

### a.6. Warning Colors

|                                                          | Shade         | Color     |
| -------------------------------------------------------- | ------------- | --------- |
| ![#FFF7E6](https://placehold.co/10x10/FFF7E6/FFF7E6.png) | 100           | `#FFF7E6` |
| ![#FEE3AE](https://placehold.co/10x10/FEE3AE/FEE3AE.png) | 200           | `#FEE3AE` |
| ![#FDD077](https://placehold.co/10x10/FDD077/FDD077.png) | 300           | `#FDD077` |
| ![#FDBD3F](https://placehold.co/10x10/FDBD3F/FDBD3F.png) | 400           | `#FDBD3F` |
| ![#FCAA07](https://placehold.co/10x10/FCAA07/FCAA07.png) | 500 (Default) | `#FCAA07` |
| ![#D99206](https://placehold.co/10x10/D99206/D99206.png) | 600           | `#D99206` |
| ![#B57A05](https://placehold.co/10x10/B57A05/B57A05.png) | 700           | `#B57A05` |
| ![#926304](https://placehold.co/10x10/926304/926304.png) | 800           | `#926304` |
| ![#6F4B03](https://placehold.co/10x10/6F4B03/6F4B03.png) | 900           | `#6F4B03` |

### a.7. Danger Colors

|                                                          | Shade         | Color     |
| -------------------------------------------------------- | ------------- | --------- |
| ![#FEF3F2](https://placehold.co/10x10/FEF3F2/FEF3F2.png) | 50            | `#FEF3F2` |
| ![#FAEBEC](https://placehold.co/10x10/FAEBEC/FAEBEC.png) | 100           | `#FAEBEC` |
| ![#EFBDC0](https://placehold.co/10x10/EFBDC0/EFBDC0.png) | 200           | `#EFBDC0` |
| ![#E49094](https://placehold.co/10x10/E49094/E49094.png) | 300           | `#E49094` |
| ![#D86268](https://placehold.co/10x10/D86268/D86268.png) | 400           | `#D86268` |
| ![#CD353C](https://placehold.co/10x10/CD353C/CD353C.png) | 500 (Default) | `#CD353C` |
| ![#B02E34](https://placehold.co/10x10/B02E34/B02E34.png) | 600           | `#B02E34` |
| ![#94262B](https://placehold.co/10x10/94262B/94262B.png) | 700           | `#94262B` |
| ![#771F23](https://placehold.co/10x10/771F23/771F23.png) | 800           | `#771F23` |
| ![#5A171A](https://placehold.co/10x10/5A171A/5A171A.png) | 900           | `#5A171A` |

```dart
import 'package:elevarm_ui/elevarm_ui.dart';

const primary = ElevarmColors.primary;
```

## B. Font Size

Font sizes are located in `ElevarmFontSizes` class.

| Name | Size     |
| ---- | -------- |
| xl5  | 48.0 dip |
| xl4  | 36.0 dip |
| xl3  | 30.0 dip |
| xl2  | 24.0 dip |
| xl   | 20.0 dip |
| lg   | 18.0 dip |
| md   | 16.0 dip |
| sm   | 14.0 dip |
| xs   | 12.0 dip |

```dart
import 'package:elevarm_ui/elevarm_ui.dart';

const fontSizeLg = ElevarmFontSizes.lg;
```

## C. Font Weight

Font weights are located in `ElevarmFontWeights` class.

| Name     | Weight |
| -------- | ------ |
| regular  | 400    |
| medium   | 500    |
| semibold | 600    |
| bold     | 700    |

```dart
import 'package:elevarm_ui/elevarm_ui.dart';

const fontWeightBold = ElevarmFontWeights.bold;
```

## C. Font Family

Font families are located in `ElevarmFonts` class.

```dart
import 'package:elevarm_ui/elevarm_ui.dart';

ElevarmFonts.init(); // Call this before `runApp`.
const poppins = ElevarmFonts.poppins();
```

## D. ThemeData

1. `ElevarmThemeData.light()`

```dart
import 'package:elevarm_ui/elevarm_ui.dart';

MaterialApp(
    theme: ElevarmThemeData.light(),
)
```

## E. Components

### e.1. `ElevarmLinearProgressIndicator`

```dart
import 'package:elevarm_ui/elevarm_ui.dart';

const ElevarmLinearProgressIndicator(
    value: 0.5,
)
```

### e.2. `ElevarmBadge`

```dart
import 'package:elevarm_ui/elevarm_ui.dart';

const ElevarmBadge(
    title: 'Mitra',
    variant: ElevarmBadgeVariant.success,
)
```

### e.3. `ElevarmOutlinedButton`

```dart
import 'package:elevarm_ui/elevarm_ui.dart';

// Button with only text
ElevarmOutlinedButton(
    onPressed: () {},
    child: Text('Button'),
)
// Button with text & icon
ElevarmOutlinedButton.icon(
    onPressed: () {},
    label: Text('Tambah'),
    icon: Icon(Icons.add),
)
// Button with only icon
ElevarmOutlinedButton.iconOnly(
    onPressed: () {},
    icon: Icon(Icons.more_horiz),
),
```

### e.4. `ElevarmElevatedButton`

```dart
import 'package:elevarm_ui/elevarm_ui.dart';

// Button with only text
ElevarmElevatedButton(
    onPressed: () {},
    child: Text('Button'),
)
// Button with text & icon
ElevarmElevatedButton.icon(
    onPressed: () {},
    label: Text('Tambah'),
    icon: Icon(Icons.add),
)
// Button with only icon
ElevarmElevatedButton.iconOnly(
    onPressed: () {},
    icon: Icon(Icons.more_horiz),
),
```

## Additional information

Contact here: majid@elevarm.com