import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

class ElevarmAvatarSizes {
  static const double xs = 24.0;
  static const double sm = 32.0;
  static const double md = 40.0;
  static const double lg = 48.0;
  static const double xl = 56.0;
  static const double xl2 = 64.0;
}

class _ElevarmAvatarOnlineIndicatorSizes {
  static const double xs = 6.0;
  static const double sm = 8.0;
  static const double md = 10.0;
  static const double lg = 12.0;
  static const double xl = 14.0;
  static const double xl2 = 16.0;

  static double fromAvatarSize(double avatarSizes) {
    if (avatarSizes == ElevarmAvatarSizes.xs) {
      return xs;
    } else if (avatarSizes == ElevarmAvatarSizes.sm) {
      return sm;
    } else if (avatarSizes == ElevarmAvatarSizes.lg) {
      return lg;
    } else if (avatarSizes == ElevarmAvatarSizes.xl) {
      return xl;
    } else if (avatarSizes == ElevarmAvatarSizes.xl2) {
      return xl2;
    } else {
      return md;
    }
  }
}

class _ElevarmAvatarIconSizes {
  static const double xs = 16.0;
  static const double sm = 20.0;
  static const double md = 24.0;
  static const double lg = 28.0;
  static const double xl = 32.0;
  static const double xl2 = 32.0;

  static double fromAvatarSize(double avatarSizes) {
    if (avatarSizes == ElevarmAvatarSizes.xs) {
      return xs;
    } else if (avatarSizes == ElevarmAvatarSizes.sm) {
      return sm;
    } else if (avatarSizes == ElevarmAvatarSizes.lg) {
      return lg;
    } else if (avatarSizes == ElevarmAvatarSizes.xl) {
      return xl;
    } else if (avatarSizes == ElevarmAvatarSizes.xl2) {
      return xl2;
    } else {
      return md;
    }
  }
}

class _ElevarmAvatarVerifiedIconSizes {
  static const double xs = 10.0;
  static const double sm = 12.0;
  static const double md = 14.0;
  static const double lg = 16.0;
  static const double xl = 18.0;
  static const double xl2 = 20.0;

  static double fromAvatarSize(double avatarSizes) {
    if (avatarSizes == ElevarmAvatarSizes.xs) {
      return xs;
    } else if (avatarSizes == ElevarmAvatarSizes.sm) {
      return sm;
    } else if (avatarSizes == ElevarmAvatarSizes.lg) {
      return lg;
    } else if (avatarSizes == ElevarmAvatarSizes.xl) {
      return xl;
    } else if (avatarSizes == ElevarmAvatarSizes.xl2) {
      return xl2;
    } else {
      return md;
    }
  }
}

class _ElevarmAvatarInitialFontSizes {
  static const double xs = ElevarmFontSizes.xs;
  static const double sm = ElevarmFontSizes.sm;
  static const double md = ElevarmFontSizes.md;
  static const double lg = ElevarmFontSizes.lg;
  static const double xl = ElevarmFontSizes.xl;
  static const double xl2 = ElevarmFontSizes.xl2;

  static double fromAvatarSize(double avatarSizes) {
    if (avatarSizes == ElevarmAvatarSizes.xs) {
      return xs;
    } else if (avatarSizes == ElevarmAvatarSizes.sm) {
      return sm;
    } else if (avatarSizes == ElevarmAvatarSizes.lg) {
      return lg;
    } else if (avatarSizes == ElevarmAvatarSizes.xl) {
      return xl;
    } else if (avatarSizes == ElevarmAvatarSizes.xl2) {
      return xl2;
    } else {
      return md;
    }
  }
}

class ElevarmAvatar extends StatelessWidget {
  final double size;
  final Color backgroundColor;

  final bool showVerifiedTick;
  final bool showOnlineIndicator;
  final double onlineIndicatorBorderWidth;
  final Color onlineIndicatorBorderColor;
  final Color onlineIndicatorColor;

  final String emptyIconAssetName;
  final Color emptyIconColor;

  final ImageProvider? image;

  final String? initial;
  final FontWeight initialFontWeight;
  final Color initialFontColor;

  const ElevarmAvatar({
    super.key,
    this.size = ElevarmAvatarSizes.md,
    this.backgroundColor = ElevarmColors.neutral100,
    this.showVerifiedTick = false,
    this.showOnlineIndicator = false,
    this.onlineIndicatorBorderWidth = 1.5,
    this.onlineIndicatorBorderColor = ElevarmColors.white,
    this.onlineIndicatorColor = ElevarmColors.success,
    this.image,
    this.initial,
    this.emptyIconAssetName = 'packages/elevarm_ui/assets/elevarm_icons/outline/users/user-01.svg',
    this.emptyIconColor = ElevarmColors.neutral400,
    this.initialFontWeight = ElevarmFontWeights.medium,
    this.initialFontColor = ElevarmColors.neutral400,
  });

  @override
  Widget build(BuildContext context) {
    Widget child;
    if (image != null) {
      child = ClipOval(
        child: Image(
          image: image!,
          fit: BoxFit.cover,
        ),
      );
    } else if (initial != null) {
      child = Text(
        initial!,
        style: ElevarmFontFamilies.inter(
          fontWeight: initialFontWeight,
          fontSize: _ElevarmAvatarInitialFontSizes.fromAvatarSize(size),
          color: initialFontColor,
        ),
      );
    } else {
      child = ElevarmIcon(
        emptyIconAssetName,
        width: _ElevarmAvatarIconSizes.fromAvatarSize(size),
        height: _ElevarmAvatarIconSizes.fromAvatarSize(size),
        color: emptyIconColor,
        fit: BoxFit.contain,
      );
    }

    return Stack(
      children: [
        Container(
          width: size,
          height: size,
          decoration: BoxDecoration(
            color: backgroundColor,
            shape: BoxShape.circle,
          ),
          child: Center(
            child: child,
          ),
        ),
        showOnlineIndicator && !showVerifiedTick
            ? Positioned(
                bottom: 0.0,
                right: 0.0,
                child: Container(
                  width:
                      _ElevarmAvatarOnlineIndicatorSizes.fromAvatarSize(size),
                  height:
                      _ElevarmAvatarOnlineIndicatorSizes.fromAvatarSize(size),
                  decoration: BoxDecoration(
                    shape: BoxShape.circle,
                    color: onlineIndicatorColor,
                    border: Border.all(
                      color: onlineIndicatorBorderColor,
                      width: onlineIndicatorBorderWidth,
                    ),
                  ),
                ),
              )
            : Container(),
        showVerifiedTick
            ? Positioned(
                bottom: 0.0,
                right: 0.0,
                child: SvgPicture.asset(
                  'packages/elevarm_ui/assets/icons/verified-tick.svg',
                  width: _ElevarmAvatarVerifiedIconSizes.fromAvatarSize(size),
                  height: _ElevarmAvatarVerifiedIconSizes.fromAvatarSize(size),
                ),
              )
            : Container(),
      ],
    );
  }
}
