import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:flutter/material.dart';

/// Wrapper [ElevarmDrawer] for desktop layout.
class ElevarmDesktopDrawer extends StatefulWidget {
  /// Currently active route path that is defined in [AppRoutes].
  final String currentRoutePath;

  final void Function(
    BuildContext context,
    String? routePath,
  ) onChangedRoutePath;

  final Duration duration;

  final List<ElevarmDrawerMenu> mainMenus;

  final List<ElevarmDrawerMenu> secondaryMenus;

  final String profileTitle;

  final String profileSubitle;

  final void Function(BuildContext context) onPressedLogout;

  final String chevronRightIconAssetName;
  final bool showHeaderLogo;
  final Widget headerTitle;
  final Widget headerSubtitle;

  const ElevarmDesktopDrawer({
    super.key,
    required this.currentRoutePath,
    required this.onChangedRoutePath,
    this.duration = const Duration(milliseconds: 200),
    this.mainMenus = const [],
    this.secondaryMenus = const [],
    required this.profileTitle,
    required this.profileSubitle,
    required this.onPressedLogout,
    this.chevronRightIconAssetName =
        'packages/elevarm_ui/assets/elevarm_icons/outline/arrows/chevron-right.svg',
    required this.headerTitle,
    required this.headerSubtitle,
    this.showHeaderLogo = true,
  });

  @override
  State<ElevarmDesktopDrawer> createState() => _ElevarmDesktopDrawerState();
}

class _ElevarmDesktopDrawerState extends State<ElevarmDesktopDrawer> {
  bool _isDrawerExpanded = true;

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Padding(
          padding: const EdgeInsets.only(right: 10.0),
          child: ElevarmDrawer(
            currentRoutePath: widget.currentRoutePath,
            onExpandDrawer: () {
              _handleExpandDrawer(true);
            },
            isDrawerExpanded: _isDrawerExpanded,
            onChangedRoutePath: widget.onChangedRoutePath,
            profileTitle: widget.profileTitle,
            profileSubitle: widget.profileSubitle,
            onPressedLogout: widget.onPressedLogout,
            mainMenus: widget.mainMenus,
            secondaryMenus: widget.secondaryMenus,
            chevronRightIconAssetName: widget.chevronRightIconAssetName,
            showHeaderLogo: widget.showHeaderLogo,
            headerTitle: widget.headerTitle,
            headerSubtitle: widget.headerSubtitle,
          ),
        ),
        Positioned(
          right: 0.0,
          top: 32.0,
          child: Material(
            color: ElevarmColors.success,
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(10.0),
            ),
            child: InkWell(
              onTap: () {
                _handleExpandDrawer(!_isDrawerExpanded);
              },
              child: AnimatedRotation(
                turns: _isDrawerExpanded ? 0.0 : 0.5,
                duration: const Duration(milliseconds: 200),
                child: ElevarmIcon(
                  widget.chevronRightIconAssetName,
                  width: 20.0,
                  height: 20.0,
                  color: ElevarmColors.white,
                ),
              ),
            ),
          ),
        )
      ],
    );
  }

  void _handleExpandDrawer(bool newValue) {
    setState(() {
      _isDrawerExpanded = newValue;
    });
  }
}
