import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:flutter/material.dart';

/// [ElevarmBadge] variants.
enum ElevarmBadgeVariant {
  success,
  danger,
  info,
}

/// App's colored badge widget.
///
/// Use [variant] to determine the styling of the badge.
class ElevarmBadge extends StatelessWidget {
  final String title;
  final ElevarmBadgeVariant variant;

  const ElevarmBadge({
    super.key,
    required this.title,
    required this.variant,
  });

  @override
  Widget build(BuildContext context) {
    Color color;
    Color backgroundColor;
    switch (variant) {
      case ElevarmBadgeVariant.success:
        color = ElevarmColors.success700;
        backgroundColor = ElevarmColors.success50;
        break;
      case ElevarmBadgeVariant.info:
        color = ElevarmColors.primary500;
        backgroundColor = ElevarmColors.primary100;
        break;
      case ElevarmBadgeVariant.danger:
      default:
        color = ElevarmColors.danger700;
        backgroundColor = ElevarmColors.danger50;
        break;
    }

    return Container(
      decoration: BoxDecoration(
        color: backgroundColor,
        borderRadius: BorderRadius.circular(16.0),
      ),
      child: Padding(
        padding: const EdgeInsets.symmetric(
          horizontal: 8.0,
          vertical: 2.0,
        ),
        child: Text(
          title,
          style: ElevarmFontFamilies.inter(
            fontSize: ElevarmFontSizes.sm,
            fontWeight: ElevarmFontWeights.medium,
            color: color,
          ),
        ),
      ),
    );
  }
}
